@@ -64,7 +64,6 @@ class IotRedisSubscriber(IotRedisBasic, Thread):
     def run(self) -> None:
         # Subscribe
         self._subscribe_channels(*self.init_channels)
-        print("Run IotRedis Consumer: Init Consumer and channels")
         while True:
             try:
                 self.pubsub.ping()
@@ -100,7 +99,6 @@ class IotRedisSubscriber(IotRedisBasic, Thread):
                 print(f"Error trying to connect to server: {err}")
                 time.sleep(1)
             else:  # If no error
-                print("Connected to subscribe")
                 break
 
     def unsubscribe_channels(self, *channels_to_unsubscribe: str) -> None:
@@ -109,9 +107,6 @@ class IotRedisSubscriber(IotRedisBasic, Thread):
         except ConnectionError as err:
             print(f"Error trying to unsusbscribe to server: {err}")
             time.sleep(1)
-        else:
-            print("Unsubscribe to: ", end="")
-            print(channels_to_unsubscribe)
 
     def data_available(self) -> bool:
         return not self.data_list.empty()
